@@ -13,11 +13,11 @@
 
 //! Defines the structure of the TOML configuration file.
 
-
-use std::{path::PathBuf, string::String, fs};
-use std::collections::HashMap;
 use indexmap::IndexMap;
 use serde::Deserialize;
+use std::collections::HashMap;
+use std::path::Path;
+use std::{fs, string::String};
 
 pub(crate) type EnvironmentVariables = IndexMap<String, EnvValue>;
 
@@ -31,7 +31,7 @@ pub(crate) struct ConfigFile {
 }
 
 impl ConfigFile {
-    pub(crate) fn load(path: &PathBuf) -> FileResult {
+    pub(crate) fn load(path: &Path) -> FileResult {
         let toml_string = match fs::read_to_string(path) {
             Ok(valid_file) => valid_file,
             Err(_) => return FileResult::NotFound,
